@@ -1,10 +1,11 @@
-from .inverted_residual import InvertedResidual
+from .inverted_residual import InvertedResidual, InvertedResidualV3
 from .make_divisible import make_divisible
 from .res_layer import ResLayer
+from .se_layer import SELayer
 from .self_attention_block import SelfAttentionBlock
 from .up_conv_block import UpConvBlock
 
 __all__ = [
     'ResLayer', 'SelfAttentionBlock', 'make_divisible', 'InvertedResidual',
-    'UpConvBlock'
+    'UpConvBlock', 'InvertedResidualV3', 'SELayer'
 ]
